@@ -19,7 +19,9 @@ class Link
   Eigen::ArrayXd computeMean(const Eigen::ArrayXd&) const;
   Eigen::ArrayXd computeMeanDerivative(const Eigen::ArrayXd&) const;
   Eigen::ArrayXd computeMeanSecondDerivative(const Eigen::ArrayXd&) const;
-
+  Eigen::ArrayXd computeMeanThirdDerivative(const Eigen::ArrayXd&) const;
+  Eigen::ArrayXd computeMeanFourthDerivative(const Eigen::ArrayXd&) const;
+  
   std::string getName() const;
 
  private:
